//
//  PileViewController.m
//  Pile
//
//  Created by aka on 09/01/19.
//  Copyright __MyCompanyName__ 2009. All rights reserved.
//

#import "PileViewController.h"

@implementation PileViewController

/*
// The designated initializer. Override to perform setup that is required before the view is loaded.
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
    if (self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil]) {
        // Custom initialization
    }
    return self;
}
*/

/*
// Implement loadView to create a view hierarchy programmatically, without using a nib.
- (void)loadView {
}
*/


// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
// ビューの読み込みが完了した時に呼び出されるメソッド
- (void)viewDidLoad
{
	// スーパー・クラスのメソッドを呼び出す
    [super viewDidLoad];
	
	// イメージ・ピッカーを作成
	imagePicker = [[UIImagePickerController alloc] init];
	// イメージ・ピッカーのデリゲートを設定
	imagePicker.delegate = self;

	// 保存確認アラートの生成と初期化
	saveAlert = [[UIAlertView alloc] init];
	saveAlert.title = @"Save Image";			// タイトルの設定
	saveAlert.message = @"Are you sure ?";		// メッセージの設定
	saveAlert.delegate = self;					// デリゲートの設定
	[saveAlert addButtonWithTitle:@"Cancel"];	// ボタンの追加
	[saveAlert addButtonWithTitle:@"OK"];		// ボタンの追加

	// 消去確認アラートの生成と初期化
	clearAlert = [[UIAlertView alloc] init];
	clearAlert.title = @"Clear Image";			// タイトルの設定
	clearAlert.message = @"Are you sure ?";		// メッセージの設定
	clearAlert.delegate = self;					// デリゲートの設定
	[clearAlert addButtonWithTitle:@"Cancel"];	// ボタンの追加
	[clearAlert addButtonWithTitle:@"OK"];		// ボタンの追加
}

// カメラを開く
- (IBAction)openCamera
{
	// カメラが利用できることを確認
	if ([UIImagePickerController isSourceTypeAvailable:UIImagePickerControllerSourceTypeCamera])
	{
		// イメージ・ピッカーのソース・タイプをカメラに設定
		imagePicker.sourceType = UIImagePickerControllerSourceTypeCamera;
		// イメージ・ピッカーを開く
		[self presentModalViewController:imagePicker animated:YES];
	}
}

// 写真アルバムを開く
- (IBAction)openPhotoLibrary
{
	// 写真アルバムが利用できることを確認
	if ([UIImagePickerController isSourceTypeAvailable:UIImagePickerControllerSourceTypePhotoLibrary])
	{
		// イメージ・ピッカーのソース・タイプを写真アルバムに設定
		imagePicker.sourceType = UIImagePickerControllerSourceTypePhotoLibrary;
		// イメージ・ピッカーを開く
		[self presentModalViewController:imagePicker animated:YES];
	}
}

// 写真が撮影・選択された時に呼び出されるデリゲート・メソッド
- (void)imagePickerController:(UIImagePickerController *)picker didFinishPickingImage:(UIImage *)image editingInfo:(NSDictionary *)editingInfo
{
	// イメージ・ピッカーを閉じる
	[self dismissModalViewControllerAnimated:YES]; 

	// イメージ・ビューの領域を取得
	CGRect	canvasRect = imageView.bounds;
	// グラフィックス・コンテクストを作成
	UIGraphicsBeginImageContext(canvasRect.size);
	// イメージ・ビューの画像を描画
	[imageView.image drawInRect:canvasRect];
	// 写真の画像をブレンド・モードを指定して描画
	[image drawInRect:canvasRect blendMode:kCGBlendModeLighten alpha:1.0];
	// グラフィックス・コンテクストから画像を取得
	UIImage *newImage = UIGraphicsGetImageFromCurrentImageContext();
	// 取得した画像をイメージ・ビューに設定
	imageView.image = newImage;
	// グラフィックス・コンテクストを解放
	UIGraphicsEndImageContext();
}

// 合成画像を保存する時に呼び出されるメソッド
- (IBAction)saveImage
{
	[saveAlert show];	// 保存確認アラートを表示
}

// 合成画像を消去する時に呼び出されるメソッド
- (IBAction)clearImage
{
	[clearAlert show];	// 消去確認アラートを表示
}

// アラートのボタンがタップされた時に呼び出されるデリゲート・メソッド
- (void)alertView:(UIAlertView *)alertView clickedButtonAtIndex:(NSInteger)buttonIndex
{
	// アラートが保存確認であり、ボタンがOKであれば、
	if (alertView == saveAlert && buttonIndex == 1)
	{
		// イメージ・ビューの画像を写真アルバムに保存
		UIImageWriteToSavedPhotosAlbum(imageView.image, nil, nil, nil);
	}

	// アラートが消去確認であり、ボタンがOKであれば、
	if (alertView == clearAlert && buttonIndex == 1)
	{
		// イメージ・ビューの画像を消去（nilに設定）
		imageView.image = nil;
	}

	// アラートの表示を消す
	[alertView dismissWithClickedButtonIndex:buttonIndex animated:YES];
}


/*
// Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
*/


- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning]; // Releases the view if it doesn't have a superview
    // Release anything that's not essential, such as cached data
}


- (void)dealloc
{
	// イメージ・ピッカーの解放
	[imagePicker release];
	// アラートの解放
	[saveAlert release];
	[clearAlert release];
	
	// スーパー・クラスのメソッドを呼び出す
    [super dealloc];
}

@end
